/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

// The ID of the most recently programmed Pushpin is 0x0041
#define RANDOM_SEED 0x0012


#define TRUE 1
#define FALSE 0
#define CRC8TABLE_ADDRESS 0x7A00
#define DECODENYBBLETABLE_ADDRESS 0x7B00

// Size of the bootloader rounded up to nearest 0x0200 boundary.
#define OS_CODE_ADDRESS 0x0E00

// Start location in flash memory of the bootloader.
#define BOOTLOADER_ADDRESS 0x0200

#define INTERRUPT_VECTOR_TABLE_SIZE 0xAE

/* 
 * All OS code should reside below this address, since 
 * this is the highest 512-byte block of flash memory 
 * that can be erased by software due to the security 
 * bytes being located at 0x7DFE and 0x&DFF.
 */
#define OS_CODE_CEILING ((unsigned int) 0x7C00)

// Available space in flash for an OS.  Includes interrupt vector.
#define FREE_FLASH_SIZE (OS_CODE_CEILING - OS_CODE_ADDRESS + 0x0100)

// A small 128-byte page of flash memory.
#define MINI_PAGE_ADDRESS ((unsigned int) 0x8000)
#define MINI_PAGE_SIZE ((unsigned int) 128)

// A normal page of flash memory.
#define FLASH_SIZE ((unsigned int) 0x8080)
#define FLASH_PAGE_SIZE ((unsigned int) 512)

// External RAM size.
#define XDATA_SIZE ((unsigned int) 2048)

// Request packet ID. 
#define IR_FRAME_START_BYTE 0x50
#define REQUEST IR_FRAME_START_BYTE

// End request packet ID.
#define END_REQUEST ((unsigned char) 0x5A)

// OS header packet ID.
#define OS_HEADER 0xBB

// Do not wait for OS packet ID.
#define DONT_WAIT_FOR_OS 0xCC
#define WAIT_FOR_OS 0xCD

// Number of main loops to wait for an OS.
#define TIMETOLISTEN 10000000

#define OS_BYTE_TIMEOUT 1000000

// Number of times a single OS byte is retransmitted.
#define NUMBER_OF_RETRANSMITS 3

sbit at 0x82 redRGB;   // P0^2
sbit at 0x83 blueRGB; // P0^3
sbit at 0x84 greenRGB;  // P0^4
