/*
 * Josh Lifton and Michael Broxton
 * MIT Media Lab
 * Copyright (c) 2002-2004. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

 /*******************************************************************************
 * PushpinHardwareV3.h revision 0
 *
 * Last modified 30NOV2001 by lifton.
 *
 * Summary:
 * This file specifies the hardware configuration for version 3 of the 
 * pushpin architecture.  The underlying processor is the Cygnal C8051F016.
 * The hardware configuration results from the Cygnal crossbar configuration
 * and should only be changed by licensed professionals.
 *******************************************************************************/

/*******************************************************************************
Port I/O Pin Assignments:
 
The Pushpin hardware architecture makes use of both pinned out 8-channel 
I/O ports on the Cygnal C8051F016 (the C8051F0xx family has four 8-channel 
I/O ports, but only two are available as actual pins on the C8051F016).  
Some of the port I/O pins are dedicated to system operation and should or 
can not be manipulated by the user and some are meant specifically to 
support user-added hardware such as sensors or other microprocessors.
********************************************************************************/

#ifdef SDCC  
/*
 * Port 0.
 */
sbit at 0x80 txPin; // Transmit pin for UART.
sbit at 0x81 rxPin; // Receive pin for UART.
sbit at 0x82 gpio0Pin; // General purpose I/O pin on sensor connector.
sbit at 0x83 gpio1Pin; // General purpose I/O pin on sensor connector.
sbit at 0x84 gpio2Pin; // General purpose I/O pin on sensor connector.
sbit at 0x85 gpio3Pin; // General purpose I/O pin on sensor connector.
sbit at 0x86 gpio4Pin; // General purpose I/O pin on sensor connector.
sbit at 0x87 gpio5Pin; // General purpose I/O pin on sensor connector.

/*
 * Port 1.
 */
sbit at 0x90 gpio6Pin; // General purpose I/O pin on sensor connector.
sbit at 0x91 gpioCommSharedPin; // Shared GPIO pin between comm and sensor connectors.
sbit at 0x92 comm0Pin; // General purpose I/O pin on comm connector.
sbit at 0x93 statusLED; // Red LED on processor board.
sbit at 0x94 comm1Pin; // General purpose I/O pin w/ interrupt on comm connector. 
sbit at 0x95 comm2Pin; // General purpose I/O pin w/ interrupt on comm connector.
sbit at 0x96 comm3Pin; // General purpose I/O pin w/ interrupt on comm connector.
sbit at 0x97 comm4Pin; // General purpose I/O pin w/ interrupt on comm connector.

/*
 * Pins used by the 4-way IR communications module.
 */
sbit at 0x91 IRChannelSelect0;
sbit at 0x92 IRChannelSelect1;
sbit at 0x94 IRChannel0;
sbit at 0x95 IRChannel1;
sbit at 0x96 IRChannel2;
sbit at 0x97 IRChannel3;
/*
 * Pins used by the RS232<->IR converter communications module.
 */
sbit at 0x94 converterSelect;
/*
 * Pins used by the LDR expansion module.
 */
sbit at 0x86 greenLED;
sbit at 0x82 yellowLED;
sbit at 0x83 amberLED;
sbit at 0x84 orangeLED;
sbit at 0x85 redLED;
sbit at 0x87 LDR;

#else      // KEIL Compiler
/*
 * Port 0.
 */
sbit txPin      =  P0^0; // Transmit pin for UART.
sbit rxPin      =  P0^1; // Receive pin for UART.
sbit gpio0Pin   =  P0^2; // General purpose I/O pin on sensor connector.
sbit gpio1Pin   =  P0^3; // General purpose I/O pin on sensor connector.
sbit gpio2Pin   =  P0^4; // General purpose I/O pin on sensor connector.
sbit gpio3Pin   =  P0^5; // General purpose I/O pin on sensor connector.
sbit gpio4Pin   =  P0^6; // General purpose I/O pin on sensor connector.
sbit gpio5Pin   =  P0^7; // General purpose I/O pin on sensor connector.

/*
 * Port 1.
 */
sbit gpio6Pin           =  P1^0; // General purpose I/O pin on sensor connector.
sbit gpioCommSharedPin  =  P1^1; // Shared GPIO pin between comm and sensor connectors.
sbit comm0Pin           =  P1^2; // General purpose I/O pin on comm connector.
sbit statusLED          =  P1^3; // Red LED on processor board.
sbit comm1Pin           =  P1^4; // General purpose I/O pin w/ interrupt on comm connector. 
sbit comm2Pin           =  P1^5; // General purpose I/O pin w/ interrupt on comm connector.
sbit comm3Pin           =  P1^6; // General purpose I/O pin w/ interrupt on comm connector.
sbit comm4Pin           =  P1^7; // General purpose I/O pin w/ interrupt on comm connector.

/*
 * Pins used by the 4-way IR communications module.
 */
sbit IRChannelSelect0 = P1^1;
sbit IRChannelSelect1 = P1^2;
sbit IRChannel0 = P1^4;
sbit IRChannel1 = P1^5;
sbit IRChannel2 = P1^6;
sbit IRChannel3 = P1^7;
/*
 * Pins used by the RS232<->IR converter communications module.
 */
sbit converterSelect = P1^4;
/*
 * Pins used by the LDR expansion module.
 */
sbit greenLED = P0^6;
sbit yellowLED = P0^2;
sbit amberLED = P0^3;
sbit orangeLED = P0^4;
sbit redLED = P0^5;
sbit LDR = P0^7;

#endif

/*******************************************************************************
Pushpin Version 3 Hardware Configuration Details

The Pushpin version 3 hardware platform is designed around a balanced 
optimization of small physical footprint, functional modularity, expandability, 
generality, and computational power.  To this end, each pushpin consists of four 
modules; power, communication, processing, and expansion modules.  Each module is
contained on a printed circuit board (PCB) measuring roughly 18mm x 18mm and 
stacks together with other modules vertically from bottom to top in the 
order listed.  The total stacked height of a pushpin varies depending on the 
modules used, but is typically on the order of 18mm as well.  A description of 
each module and the connections between them follow.

Power Module:
Currently the power module consists simply of two capacitors and two 20-gauge 
wire brads that protrude from the bottom of an otherwise empty PCB.  One pin connects to 
power, the to ground.  The power source itself is a substrate made up of layers 
of conductive silicon rubber interlaced with layers of insulating silicon 
rubber.  Power is supplied to the pushpin when the pushpin power pins are pushed 
into the power substrate, hence the name pushpin.  The power pins differ in 
length so as to make contact with the appropriate power layer.  Additionally, 
the power pin, being the longer of the two, is insulated with a spray-on 
adhesive except for the very tip so as to prevent electrically shorting the 
power and ground planes.  Other power sources can easily take the place of the 
pins as long as they provide 2.7VDC to 3.3VDC.  The total power consumed depends 
strongly on which expansion, processing, and communication modules are used and how 
they are used.  For example, the processing module has several different modes of 
operation, each requiring a different amount of power.  Typical current consumption 
of the processing board running at 22MHz with all necessary peripherals enabled is 
roughly 10mA.

Communication Module:
The communication module contains all the hardware needed to transmit a signal 
from a typical UART transmit line and condition a received signal to pass on to 
a typical UART receive line.  That is, the communication board consists of all 
communication hardware except the UART itself, which is built into the processor 
on the processor module.  Currently, there are two communication modules available 
for pushpins; a capacitive coupling module and an infrared module.  Both modules 
require data to conform to certain format; a one must follow every zero.  Even given
the worst case scenario of inserting a one after every data bit, though, both 
modules can run up to 115kbps.

Processing Module:
All hardware supporting the operation of the microprocessor as well as the 
microprocessor itself is contained on the processor module.  The pushpin version 
3 processor module consists of a Cygnal C8051F016 microprocessor, a 25-pin 
board-to-board connector, an LED and associated resistor, a 22.118MHz crystal 
and two associated capacitors, a capacitor across the power supply, and a pull-up 
resistor on the /reset pin of the processor.  The processor module connects to 
the communications module below it with twelve electrical connections: power, 
ground, transmit, receive, a 12-bit digital-to-analog converter, a 10-bit analog-to-digital 
channel, and six general purpose IO pins, four of which can act as external interrupts.
The processor module connects to the expansion module above with 27 electrical 
connections: power, ground, a 12-bit digitial-to-analog converter, seven 10-bit 
analog-to-digital channels, eight general purpose I/O pins, and four JTAG pins 
through which the processor is programmed and debugged. The DAC and one of the GPIO 
pins are the same as those that connect with the communication module.  All 
connections to the expansion module are through a single 25-pin connector, except for 
the receive and transmit lines, which each has its own optional connecter.

Expansion Module:
The expansion module contains all the user specified hardware.  It connects 
down to the processor module by means of the 25-pin connector already detailed 
and optionally by the transmit and receive vias.  Resources available to the 
expansion module through the 25-pin connector are tailored toward supporting 
sensors, actuators, interrupt sources, and other processors provided by the user. 

********************************************************************************/
